@@ -55,6 +55,7 @@ impl Icons {
     const LANG_CSHARP: char     = '\u{f031b}'; // 󰌛
     const LANG_D: char          = '\u{e7af}';  // 
     const LANG_ELIXIR: char     = '\u{e62d}';  // 
+    const LANG_FENNEL: char     = '\u{e6af}';  // 
     const LANG_FORTRAN: char    = '\u{f121a}'; // 󱈚
     const LANG_FSHARP: char     = '\u{e7a7}';  // 
     const LANG_GO: char         = '\u{e65e}';  // 
@@ -177,6 +178,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".eslintrc.json"      => Icons::ESLINT,         // 
     ".eslintrc.yaml"      => Icons::ESLINT,         // 
     ".eslintrc.yml"       => Icons::ESLINT,         // 
+    ".fennelrc"           => Icons::CONFIG,         // 
     ".gitattributes"      => Icons::GIT,            // 
     ".gitconfig"          => Icons::GIT,            // 
     ".gitignore"          => Icons::GIT,            // 
@@ -453,6 +455,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "fish"           => Icons::SHELL_CMD,        // 
     "flac"           => Icons::AUDIO,            // 
     "flv"            => Icons::VIDEO,            // 
+    "fnl"            => Icons::LANG_FENNEL,      // 
     "fnt"            => Icons::FONT,             // 
     "fodg"           => Icons::VECTOR,           // 󰕙
     "fodp"           => Icons::SLIDE,            // 
